pub struct RasterizerSettings {
pub render_mode: RenderMode,
pub composite_mode: CompositeMode,
pub pixel_format: PixelFormat,
pub offset: (u16, u16),
}Expand description
Settings used when rasterizing a scene into a pixmap.
Fields
render_mode: RenderModeWhether to prioritize speed or quality when rendering.
For most cases (especially for real-time rendering), it is highly recommended to set
this to RenderMode::OptimizeSpeed. If color accuracy is a more significant concern,
then you can set this to RenderMode::OptimizeQuality.
Currently, the only difference this makes is that when choosing RenderMode::OptimizeSpeed,
rasterization will happen using u8/u16,
while RenderMode::OptimizeQuality will use a f32-based pipeline.
composite_mode: CompositeModeHow rendered content is composited into the destination.
pixel_format: PixelFormatPixel format of the destination.
offset: (u16, u16)Offset in destination pixels where the render context origin is placed.
See RenderContext::render_with for more information.